import { world, system, Player } from "@minecraft/server";

system.runInterval(() => {
    const overworld = world.getDimension("overworld");
    const nether = world.getDimension("nether");
    const the_end = world.getDimension("the_end");

    // Collect entities from all dimensions
    let entities = overworld.getEntities({ excludeFamilies: ['flag'], excludeTypes: ["sh:indique", "sh:fuel_machine"] });
    entities = entities.concat(nether.getEntities({excludeFamilies: ['flag'], excludeTypes: ["sh:indique", "sh:fuel_machine"]}));
    entities = entities.concat(the_end.getEntities({excludeFamilies: ['flag'], excludeTypes: ["sh:indique", "sh:fuel_machine"]}));

    for (const entity of entities) {
        const healthComponent = entity.getComponent("minecraft:health");
   
        const lines = entity.nameTag ? entity.nameTag.split("\n") : [];
        const exeName = lines[0];
    
        if (healthComponent) {
            const currentHealth = healthComponent.currentValue;
            const maxHealth = healthComponent.defaultValue;
            const health = Math.floor(currentHealth);

            // Color gradient for health representation
            let healthColor = "§e"; // Default yellow
            let healthSymbol = "";

            // Determine health color and symbol based on health percentage
            const healthPercentage = (currentHealth / maxHealth) * 100;
            if (healthPercentage > 66) {
                healthColor = "§a"; // Green for high health
                healthSymbol = "";
            } else if (healthPercentage > 33) {
                healthColor = "§6"; // Gold for medium health
                healthSymbol = "";
            } else {
                healthColor = "§c"; // Red for low health
                healthSymbol = "";
            }

            // Health bar visualization
            const healthBarLength = 10;
            const filledLength = Math.floor((currentHealth / maxHealth) * healthBarLength);
            const emptyLength = healthBarLength - filledLength;
            const healthBar = `§a${"▮".repeat(filledLength)}§c${"▯".repeat(emptyLength)}`;

            if (entity.typeId !== "minecraft:player") {
                const entityId = entity.typeId;
                const entityNameById = entityId.split(":")[1];
                entity.nameTag = `[ ${entityNameById} ]\n${healthColor}${healthSymbol} ${health} / ${maxHealth}\n${healthBar}`;
            } else {
                if (exeName != undefined) {
                    entity.nameTag = `[ ${exeName} ]\n${healthColor}${healthSymbol} ${health}\n${healthBar}`;
                } else {
                    entity.nameTag = `${healthColor}${healthSymbol} ${health}\n${healthBar}`;
                }
            }
        }
    }
}, 20); // Run every second (20 ticks)